==> haskell-ansi-wl-pprint-0.6.9-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.9
id: ansi-wl-pprint-0.6.9-8GHEGH1lUTqAkRwSafnocf
key: ansi-wl-pprint-0.6.9-8GHEGH1lUTqAkRwSafnocf
license: BSD-3-Clause
maintainer: Edward Kmett <ekmett@gmail.com>
author: Daan Leijen, Max Bolingbroke
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.
category: User Interfaces, Text
abi: cec53a3c61de63147c71024d77aebdea
exposed: True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ansi-wl-pprint-0.6.9
hs-libraries: HSansi-wl-pprint-0.6.9-8GHEGH1lUTqAkRwSafnocf
depends:
    ansi-terminal-0.9.1-DB3Zf3I0Zem5oqZIKoyRWZ base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-wl-pprint-0.6.9-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-wl-pprint
version: 0.6.9
id: ansi-wl-pprint-0.6.9-2omI3jlOeR11cioOWuwupk
key: ansi-wl-pprint-0.6.9-2omI3jlOeR11cioOWuwupk
license: BSD-3-Clause
maintainer: Edward Kmett <ekmett@gmail.com>
author: Daan Leijen, Max Bolingbroke
homepage: http://github.com/ekmett/ansi-wl-pprint
synopsis: The Wadler/Leijen Pretty Printer for colored ANSI terminal output
description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.
category: User Interfaces, Text
abi: 6f22c80b98784b3484e5ac5d9be8b484
exposed: True
exposed-modules:
    Text.PrettyPrint.ANSI.Leijen Text.PrettyPrint.ANSI.Leijen.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/ansi-wl-pprint-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ansi-wl-pprint-0.6.9
hs-libraries: HSansi-wl-pprint-0.6.9-2omI3jlOeR11cioOWuwupk
depends:
    ansi-terminal-0.9.1-4EGEPOXIA9UHNrgfDydiTP base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
